@@ -65,6 +65,7 @@ from psutil.tests import get_test_subprocess
 from psutil.tests import get_winver
 from psutil.tests import GLOBAL_TIMEOUT
 from psutil.tests import pyrun
+from psutil.tests import PYPY
 from psutil.tests import PYTHON
 from psutil.tests import reap_children
 from psutil.tests import retry_before_failing
@@ -154,6 +155,12 @@ class TestProcess(unittest.TestCase):
                 with self.assertRaises(psutil.AccessDenied):
                     psutil.Process().send_signal(sig)
                 assert fun.called
+            # Sending a signal to process with PID 0 is not allowed as
+            # it would affect every process in the process group of
+            # the calling process (os.getpid()) instead of PID 0").
+            if 0 in psutil.pids():
+                p = psutil.Process(0)
+                self.assertRaises(ValueError, p.send_signal, signal.SIGTERM)
 
     def test_wait(self):
         # check exit code signal
@@ -261,9 +268,11 @@ class TestProcess(unittest.TestCase):
     def test_cpu_times(self):
         times = psutil.Process().cpu_times()
         assert (times.user > 0.0) or (times.system > 0.0), times
+        assert (times.children_user >= 0.0), times
+        assert (times.children_system >= 0.0), times
         # make sure returned values can be pretty printed with strftime
-        time.strftime("%H:%M:%S", time.localtime(times.user))
-        time.strftime("%H:%M:%S", time.localtime(times.system))
+        for name in times._fields:
+            time.strftime("%H:%M:%S", time.localtime(getattr(times, name)))
 
     # Test Process.cpu_times() against os.times()
     # os.times() is broken on Python 2.6
@@ -273,8 +282,8 @@ class TestProcess(unittest.TestCase):
 
     @unittest.skipUnless(sys.version_info > (2, 6, 1) and not OSX,
                          'os.times() is not reliable on this Python version')
-    def test_cpu_times2(self):
-        user_time, kernel_time = psutil.Process().cpu_times()
+    def test_cpu_times_2(self):
+        user_time, kernel_time = psutil.Process().cpu_times()[:2]
         utime, ktime = os.times()[:2]
 
         # Use os.times()[:2] as base values to compare our results
@@ -417,6 +426,11 @@ class TestProcess(unittest.TestCase):
             self.assertGreaterEqual(value, 0)
             if name in dir(resource):
                 self.assertEqual(value, getattr(resource, name))
+                # XXX - On PyPy RLIMIT_INFINITY returned by
+                # resource.getrlimit() is reported as a very big long
+                # number instead of -1. It looks like a bug with PyPy.
+                if PYPY:
+                    continue
                 self.assertEqual(p.rlimit(value), resource.getrlimit(value))
             else:
                 ret = p.rlimit(value)
@@ -547,6 +561,8 @@ class TestProcess(unittest.TestCase):
                 thread.stop()
 
     @retry_before_failing()
+    # see: https://travis-ci.org/giampaolo/psutil/jobs/111842553
+    @unittest.skipIf(OSX and TRAVIS, "")
     def test_threads_2(self):
         p = psutil.Process()
         if OPENBSD:
@@ -868,13 +884,20 @@ class TestProcess(unittest.TestCase):
         p = psutil.Process()
         files = p.open_files()
         self.assertFalse(TESTFN in files)
-        with open(TESTFN, 'w'):
+        with open(TESTFN, 'wb') as f:
+            f.write(b'x' * 1024)
+            f.flush()
             # give the kernel some time to see the new file
-            call_until(p.open_files, "len(ret) != %i" % len(files))
-            filenames = [x.path for x in p.open_files()]
-            self.assertIn(TESTFN, filenames)
-        for file in filenames:
-            assert os.path.isfile(file), file
+            files = call_until(p.open_files, "len(ret) != %i" % len(files))
+            for file in files:
+                if file.path == TESTFN:
+                    if LINUX:
+                        self.assertEqual(file.position, 1024)
+                    break
+            else:
+                self.fail("no file found; files=%s" % repr(files))
+        for file in files:
+            assert os.path.isfile(file.path), file
 
         # another process
         cmdline = "import time; f = open(r'%s', 'r'); time.sleep(60);" % TESTFN
@@ -895,20 +918,20 @@ class TestProcess(unittest.TestCase):
     @unittest.skipIf(BSD, "broken on BSD, see #595")
     @unittest.skipIf(APPVEYOR,
                      "can't find any process file on Appveyor")
-    def test_open_files2(self):
+    def test_open_files_2(self):
         # test fd and path fields
         with open(TESTFN, 'w') as fileobj:
             p = psutil.Process()
-            for path, fd in p.open_files():
-                if path == fileobj.name or fd == fileobj.fileno():
+            for file in p.open_files():
+                if file.path == fileobj.name or file.fd == fileobj.fileno():
                     break
             else:
                 self.fail("no file found; files=%s" % repr(p.open_files()))
-            self.assertEqual(path, fileobj.name)
+            self.assertEqual(file.path, fileobj.name)
             if WINDOWS:
-                self.assertEqual(fd, -1)
+                self.assertEqual(file.fd, -1)
             else:
-                self.assertEqual(fd, fileobj.fileno())
+                self.assertEqual(file.fd, fileobj.fileno())
             # test positions
             ntuple = p.open_files()[0]
             self.assertEqual(ntuple[0], ntuple.path)
@@ -1686,6 +1709,11 @@ class TestFetchAllProcesses(unittest.TestCase):
                 assert f.fd == -1, f
             else:
                 self.assertIsInstance(f.fd, int)
+            if LINUX:
+                self.assertIsInstance(f.position, int)
+                self.assertGreaterEqual(f.position, 0)
+                self.assertIn(f.mode, ('r', 'w', 'a', 'r+', 'a+'))
+                self.assertGreater(f.flags, 0)
             if BSD and not f.path:
                 # XXX see: https://github.com/giampaolo/psutil/issues/595
                 continue
@@ -1927,7 +1955,7 @@ class TestNonUnicode(unittest.TestCase):
 
     @classmethod
     def tearDownClass(cls):
-        shutil.rmtree(cls.temp_directory)
+        shutil.rmtree(cls.temp_directory, ignore_errors=True)
 
     def setUp(self):
         reap_children()
