@@ -31,7 +31,7 @@ from psutil import WINDOWS
 from psutil._compat import long
 from psutil.tests import AF_INET6
 from psutil.tests import APPVEYOR
-from psutil.tests import check_ip_address
+from psutil.tests import check_net_address
 from psutil.tests import DEVNULL
 from psutil.tests import enum
 from psutil.tests import get_test_subprocess
@@ -246,7 +246,8 @@ class TestSystemAPIs(unittest.TestCase):
         self.assertGreaterEqual(physical, 1)
         self.assertGreaterEqual(logical, physical)
 
-    def test_sys_cpu_times(self):
+    def test_cpu_times(self):
+        # Check type, value >= 0, str().
         total = 0
         times = psutil.cpu_times()
         sum(times)
@@ -274,7 +275,8 @@ class TestSystemAPIs(unittest.TestCase):
         #                                     msg="%s %s" % (new_t, last_t))
         #         last = new
 
-    def test_sys_cpu_times2(self):
+    def test_cpu_times_time_increases(self):
+        # Make sure time increases between calls.
         t1 = sum(psutil.cpu_times())
         time.sleep(0.1)
         t2 = sum(psutil.cpu_times())
@@ -282,7 +284,8 @@ class TestSystemAPIs(unittest.TestCase):
         if not difference >= 0.05:
             self.fail("difference %s" % difference)
 
-    def test_sys_per_cpu_times(self):
+    def test_per_cpu_times(self):
+        # Check type, value >= 0, str().
         for times in psutil.cpu_times(percpu=True):
             total = 0
             sum(times)
@@ -314,7 +317,9 @@ class TestSystemAPIs(unittest.TestCase):
         #                 new_t, last_t, msg="%s %s" % (lastcpu, newcpu))
         #     last = new
 
-    def test_sys_per_cpu_times_2(self):
+    def test_per_cpu_times_2(self):
+        # Simulate some work load then make sure time have increased
+        # between calls.
         tot1 = psutil.cpu_times(percpu=True)
         stop_at = time.time() + 0.1
         while True:
@@ -328,6 +333,16 @@ class TestSystemAPIs(unittest.TestCase):
                 return
         self.fail()
 
+    def test_cpu_times_comparison(self):
+        # Make sure the sum of all per cpu times is almost equal to
+        # base "one cpu" times.
+        base = psutil.cpu_times()
+        per_cpu = psutil.cpu_times(percpu=True)
+        summed_values = base._make([sum(num) for num in zip(*per_cpu)])
+        for field in base._fields:
+            self.assertAlmostEqual(
+                getattr(base, field), getattr(summed_values, field), delta=1)
+
     def _test_cpu_percent(self, percent, last_ret, new_ret):
         try:
             self.assertIsInstance(percent, float)
@@ -338,14 +353,14 @@ class TestSystemAPIs(unittest.TestCase):
             raise AssertionError("\n%s\nlast=%s\nnew=%s" % (
                 err, pprint.pformat(last_ret), pprint.pformat(new_ret)))
 
-    def test_sys_cpu_percent(self):
+    def test_cpu_percent(self):
         last = psutil.cpu_percent(interval=0.001)
         for x in range(100):
             new = psutil.cpu_percent(interval=None)
             self._test_cpu_percent(new, last, new)
             last = new
 
-    def test_sys_per_cpu_percent(self):
+    def test_per_cpu_percent(self):
         last = psutil.cpu_percent(interval=0.001, percpu=True)
         self.assertEqual(len(last), psutil.cpu_count())
         for x in range(100):
@@ -354,7 +369,7 @@ class TestSystemAPIs(unittest.TestCase):
                 self._test_cpu_percent(percent, last, new)
             last = new
 
-    def test_sys_cpu_times_percent(self):
+    def test_cpu_times_percent(self):
         last = psutil.cpu_times_percent(interval=0.001)
         for x in range(100):
             new = psutil.cpu_times_percent(interval=None)
@@ -363,7 +378,7 @@ class TestSystemAPIs(unittest.TestCase):
             self._test_cpu_percent(sum(new), last, new)
             last = new
 
-    def test_sys_per_cpu_times_percent(self):
+    def test_per_cpu_times_percent(self):
         last = psutil.cpu_times_percent(interval=0.001, percpu=True)
         self.assertEqual(len(last), psutil.cpu_count())
         for x in range(100):
@@ -374,7 +389,7 @@ class TestSystemAPIs(unittest.TestCase):
                 self._test_cpu_percent(sum(cpu), last, new)
             last = new
 
-    def test_sys_per_cpu_times_percent_negative(self):
+    def test_per_cpu_times_percent_negative(self):
         # see: https://github.com/giampaolo/psutil/issues/645
         psutil.cpu_times_percent(percpu=True)
         zero_times = [x._make([0 for x in range(len(x._fields))])
@@ -419,15 +434,10 @@ class TestSystemAPIs(unittest.TestCase):
                      "os.statvfs() function not available on this platform")
     def test_disk_usage_unicode(self):
         # see: https://github.com/giampaolo/psutil/issues/416
-        # XXX this test is not really reliable as it always fails on
-        # Python 3.X (2.X is fine)
-        try:
-            safe_rmdir(TESTFN_UNICODE)
-            os.mkdir(TESTFN_UNICODE)
-            psutil.disk_usage(TESTFN_UNICODE)
-            safe_rmdir(TESTFN_UNICODE)
-        except UnicodeEncodeError:
-            pass
+        safe_rmdir(TESTFN_UNICODE)
+        self.addCleanup(safe_rmdir, TESTFN_UNICODE)
+        os.mkdir(TESTFN_UNICODE)
+        psutil.disk_usage(TESTFN_UNICODE)
 
     @unittest.skipIf(POSIX and not hasattr(os, 'statvfs'),
                      "os.statvfs() function not available on this platform")
@@ -573,7 +583,7 @@ class TestSystemAPIs(unittest.TestCase):
                         # AddressValueError: Only hex digits permitted in
                         # u'c6f3%lxcbr0' in u'fe80::c8e0:fff:fe54:c6f3%lxcbr0'
                         if addr.family != AF_INET6:
-                            check_ip_address(ip, addr.family)
+                            check_net_address(ip, addr.family)
                 # broadcast and ptp addresses are mutually exclusive
                 if addr.broadcast:
                     self.assertIsNone(addr.ptp)
@@ -588,6 +598,23 @@ class TestSystemAPIs(unittest.TestCase):
         elif WINDOWS:
             self.assertEqual(psutil.AF_LINK, -1)
 
+    def test_net_if_addrs_mac_null_bytes(self):
+        # Simulate that the underlying C function returns an incomplete
+        # MAC address. psutil is supposed to fill it with null bytes.
+        # https://github.com/giampaolo/psutil/issues/786
+        if POSIX:
+            ret = [('em1', psutil.AF_LINK, '06:3d:29', None, None, None)]
+        else:
+            ret = [('em1', -1, '06-3d-29', None, None, None)]
+        with mock.patch('psutil._psplatform.net_if_addrs',
+                        return_value=ret) as m:
+            addr = psutil.net_if_addrs()['em1'][0]
+            assert m.called
+            if POSIX:
+                self.assertEqual(addr.address, '06:3d:29:00:00:00')
+            else:
+                self.assertEqual(addr.address, '06-3d-29-00-00-00')
+
     @unittest.skipIf(TRAVIS, "EPERM on travis")
     def test_net_if_stats(self):
         nics = psutil.net_if_stats()
@@ -651,6 +678,15 @@ class TestSystemAPIs(unittest.TestCase):
             assert user.started > 0.0, user
             datetime.datetime.fromtimestamp(user.started)
 
+    def test_cpu_stats(self):
+        # Tested more extensively in per-platform test modules.
+        infos = psutil.cpu_stats()
+        for name in infos._fields:
+            value = getattr(infos, name)
+            self.assertGreaterEqual(value, 0)
+            if name in ('ctx_switches', 'interrupts'):
+                self.assertGreater(value, 0)
+
 
 if __name__ == '__main__':
     run_test_module_by_name(__file__)
